Ui

Struct Ui 

pub struct Ui {
    pub columns: Vec<UiColumn>,
}
UI-specific settings for the interactive search.

Fields

columns: Vec<UiColumn>

Columns to display in interactive search, from left to right. The indicator column (“ > “) is always shown first implicitly. The “command” column should be last as it expands to fill remaining space. Can be simple strings or objects with type and width.

Implementations

Source

impl Ui

pub fn validate(&self) -> Result<()>

Validate the UI configuration. Returns an error if more than one column has expand = true.